from pequod_cli.service import CoreService


class ClusterController(CoreService):
    def __init__(self, endpoints, credentials):
        super().__init__(endpoints, 'cluster-controller', credentials)

    def get_state(self):
        return self.get('/state')